Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/max31856_simpletest.py
    :caption: examples/max31856_simpletest.py
    :linenos:

Thresholds and Fault example
----------------------------

Example showing how to use thresholds

.. literalinclude:: ../examples/max31856_thresholds_and_faults.py
    :caption: examples/max31856_thresholds_and_faults.py
    :linenos:
